==> rippled-1.3.1.tar.gz: rippled-1.3.1/src/ripple/nodestore/impl/EncodedBlob.cpp <==
//------------------------------------------------------------------------------
/*
    This file is part of rippled: https://github.com/ripple/rippled
    Copyright (c) 2012, 2013 Ripple Labs Inc.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose  with  or without fee is hereby granted, provided that the above
    copyright notice and this permission notice appear in all copies.

    THE  SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
    WITH  REGARD  TO  THIS  SOFTWARE  INCLUDING  ALL  IMPLIED  WARRANTIES  OF
    MERCHANTABILITY  AND  FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
    ANY  SPECIAL ,  DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
    WHATSOEVER  RESULTING  FROM  LOSS  OF USE, DATA OR PROFITS, WHETHER IN AN
    ACTION  OF  CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
//==============================================================================

#include <ripple/nodestore/impl/EncodedBlob.h>
#include <cstring>

namespace ripple {
namespace NodeStore {

void
EncodedBlob::prepare (
    std::shared_ptr<NodeObject> const& object)
{
    m_key = object->getHash().begin ();

    auto ret = m_data.alloc(object->getData ().size () + 9);

    // the first 8 bytes are unused
    memset (ret, 0, 8);

    ret[8] = static_cast<std::uint8_t> (object->getType ());

    memcpy (ret + 9,
        object->getData ().data(),
        object->getData ().size());
}

}
}

==> rippled-1.9.4.tar.gz: rippled-1.9.4/src/ripple/nodestore/impl/EncodedBlob.cpp <==
//------------------------------------------------------------------------------
/*
    This file is part of rippled: https://github.com/ripple/rippled
    Copyright (c) 2012, 2013 Ripple Labs Inc.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose  with  or without fee is hereby granted, provided that the above
    copyright notice and this permission notice appear in all copies.

    THE  SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
    WITH  REGARD  TO  THIS  SOFTWARE  INCLUDING  ALL  IMPLIED  WARRANTIES  OF
    MERCHANTABILITY  AND  FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
    ANY  SPECIAL ,  DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
    WHATSOEVER  RESULTING  FROM  LOSS  OF USE, DATA OR PROFITS, WHETHER IN AN
    ACTION  OF  CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
//==============================================================================

#include <ripple/nodestore/impl/EncodedBlob.h>
#include <cstring>

namespace ripple {
namespace NodeStore {

void
EncodedBlob::prepare(std::shared_ptr<NodeObject> const& object)
{
    m_key = object->getHash().begin();

    auto ret = m_data.alloc(object->getData().size() + 9);

    // the first 8 bytes are unused
    std::memset(ret, 0, 8);

    ret[8] = static_cast<std::uint8_t>(object->getType());

    std::memcpy(ret + 9, object->getData().data(), object->getData().size());
}

}  // namespace NodeStore
}  // namespace ripple
